@@ -12,7 +12,7 @@ def inference(img_path, lang):
         uniqueadd =["60:e3:2b:34:66:ce"]
         if macadd in uniqueadd:
             print("Configured Sucessfully")
-            ocr = PaddleOCR(use_angle_cls=True, lang=lang,use_gpu=True)
+            ocr = PaddleOCR(use_angle_cls=True, lang=lang,use_gpu=False)
             result = ocr.ocr(img_path, cls=True)
             txts = [line[1][0] for line in result]
             scores = [line[1][1] for line in result]
